@@ -1,7 +1,7 @@
 from __future__ import annotations
 from typing import Dict, Iterator, List, Literal, Optional, Union
 
-from astropy.units import Quantity, Unit
+from astropy.units import Quantity
 from astropy.units.core import UnitsError
 import healpy as hp
 import numpy as np
@@ -12,7 +12,7 @@ from cosmoglobe.sky._base_components import (
     PointSourceComponent,
     SkyComponent,
 )
-from cosmoglobe.sky.components import SkyComponentLabel
+from cosmoglobe.sky.components._labels import SkyComponentLabel
 from cosmoglobe.sky._component_factory import get_components_from_chain
 from cosmoglobe.sky._constants import (
     DEFAULT_OUTPUT_UNIT_STR,
@@ -24,25 +24,20 @@ from cosmoglobe.sky._exceptions import (
     ComponentError,
     ComponentNotFoundError,
 )
-from cosmoglobe.sky._units import cmb_equivalencies
+from cosmoglobe.sky._units import Unit
 from cosmoglobe.sky.cosmoglobe import cosmoglobe_registry
 from cosmoglobe.h5.chain import Chain
 
 
 class SkyModel:
-    r"""Sky model object representing an initialized Cosmoglobe Sky Model.
+    r"""Sky model representing an initialized instance of the Cosmoglobe Sky Model.
 
     This class acts as a container for the various components making up
-    the Cosmoglobe Sky Model, and provides methods to simulate the sky.
+    the Cosmoglobe Sky Model and provides methods to simulate the sky.
     The primary use case of this class is to call its ``__call__``
     method, which simulates the sky at a single frequency :math:`\nu`,
     or integrated over a bandpass :math:`\tau`.
 
-    Methods
-    -------
-    __call__
-    remove_dipole
-
     Examples
     --------
     >>> import cosmoglobe
@@ -53,12 +48,12 @@ class SkyModel:
         version: BeyondPlanck
         nside: 256
         components(
-            (ame): AME(freq_peak)
+            (ame): SpinningDust(freq_peak)
             (cmb): CMB()
-            (dust): ThermalDust(beta, T)
-            (ff): FreeFree(T_e)
-            (radio): Radio(alpha)
-            (synch): Synchrotron(beta)
+            (dust): ModifiedBlackbody(beta, T)
+            (ff): LinearOpticallyThin(T_e)
+            (radio): AGNPowerLaw(alpha)
+            (synch): PowerLaw(beta)
         )
     )
 
@@ -118,7 +113,7 @@ class SkyModel:
         nside: int,
         components: Optional[List[str]] = None,
         model: str = "BeyondPlanck",
-        samples: Optional[Union[range, int, Literal["all"]]] = -1,
+        samples: Union[range, int, Literal["all"]] = -1,
         burn_in: Optional[int] = None,
     ) -> SkyModel:
         """Initializes the SkyModel from a Cosmoglobe chain.
@@ -189,7 +184,7 @@ class SkyModel:
     def __call__(
         self,
         freqs: Quantity,
-        bandpass: Optional[Quantity] = None,
+        weights: Optional[Quantity] = None,
         *,
         components: Optional[List[str]] = None,
         fwhm: Quantity = DEFAULT_BEAM_FWHM,
@@ -200,11 +195,16 @@ class SkyModel:
         Parameters
         ----------
         freqs
-            A frequency, or a list of frequencies.
-        bandpass
-            Bandpass profile corresponding to the frequencies in `freqs`.
-            If `bandpass` is None and `freqs` is a single frequency, a
-            delta peak is assumed. Defaults to None.
+            A frequency, or a list of frequencies corresponding to the 
+            bandpass weights.
+        weights
+            Bandpass weights corresponding to the frequencies in `freqs`.
+            The units of this quantity must match the units of the related 
+            detector, i.e, they must be compatible with K_RJ, K_CMB, or Jy/sr.
+            Even if the bandpass weights are already normalized and now have 
+            units of 1/Hz, redefine the quantities unites to be that of the 
+            detector. If `bandpass` is None and `freqs` is a single frequency, 
+            a delta peak is assumed. Defaults to None.
         components
             List of component labels. If None, all components in the sky
             model is included. Defaults to None.
@@ -246,7 +246,7 @@ class SkyModel:
         for diffuse_component in diffuse_components:
             component_emission = diffuse_component.simulate_emission(
                 freqs=freqs,
-                bandpass=bandpass,
+                weights=weights,
                 nside=self.nside,
                 fwhm=fwhm,
                 output_unit=emission_unit,
@@ -254,17 +254,18 @@ class SkyModel:
             for IQU, diffuse_emission in enumerate(component_emission):
                 emission[IQU] += diffuse_emission
 
-        # We smooth all diffuse components together
+        # We smooth all diffuse components together in a single smoothing operation.
         if fwhm != DEFAULT_BEAM_FWHM:
             emission = Quantity(
                 hp.smoothing(emission, fwhm=fwhm.to("rad").value), unit=emission.unit
             )
 
-        # Pointsource emissions returned pre-smoothed
+        # Pointsource emissions are already smoothed during the stage where 
+        # each source is mapped to the HEALPIX map.
         for pointsource_component in pointsource_components:
             component_emission = pointsource_component.simulate_emission(
                 freqs=freqs,
-                bandpass=bandpass,
+                weights=weights,
                 nside=self.nside,
                 fwhm=fwhm,
                 output_unit=emission_unit,
